import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-create-command-group',
  templateUrl: './create-command-group.component.html',
  styleUrls: ['./create-command-group.component.css']
})
export class CreateCommandGroupComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  availableCommands: any[] = [];
  selectedCommands: any[] = [];
  groupName: string = '';
  enabled: boolean = true;
  editing: boolean = false;
  loading: boolean = false;
  private apiUrl = `${this.baseUrl}/commands`;

  constructor(
    private http: HttpClient,
    private dialogRef: MatDialogRef<CreateCommandGroupComponent>,
    private toastService: ToastrService,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {}

  ngOnInit(): void {
    this.loadAvailableCommands();

    if (this.data && this.data.group) {
      this.editing = true;
      this.loadGroupData(this.data.group);
    }
  }

  loadAvailableCommands(): void {
    this.loading = true;
    this.http.get<any>(this.apiUrl).subscribe(
      (data) => {
        this.availableCommands = data['hydra:member'];
        this.loading = false;
      },
      (error) => {
        console.error('Error fetching available commands', error);
        this.loading = false;
      }
    );
  }

  loadGroupData(group: any): void {
    this.groupName = group.name;
    this.enabled = group.enabled;
    this.selectedCommands = group.commands;
  }

  addCommand(command: any): void {
    this.selectedCommands.push(command);
  }

  removeCommand(command: any): void {
    const index = this.selectedCommands.indexOf(command);
    if (index >= 0) {
      this.selectedCommands.splice(index, 1);
    }
  }

  onSubmit(): void {
    const payload = {
      name: this.groupName,
      commands: this.selectedCommands.map(cmd => cmd['@id']),
      enabled: this.enabled
    };

    if (this.editing) {
      const groupId = this.data.group.uuid;
      this.http.patch(`${this.baseUrl}/command-groups/${groupId}`, payload).subscribe({
        next: () => {
          this.toastService.success('Grupo de comandos actualizado con éxito');
          this.dialogRef.close();
        },
        error: (error) => {
          console.error('Error actualizando el grupo de comandos', error);
        }
      });
    } else {
      this.http.post(`${this.baseUrl}/command-groups`, payload).subscribe({
        next: () => {
          this.toastService.success('Grupo de comandos creado con éxito');
          this.dialogRef.close();
        },
        error: (error) => {
          console.error('Error creando el grupo de comandos', error);
        }
      });
    }
  }

  close(): void {
    this.dialogRef.close();
  }
}
